/******************************************************************************
 Loading of external libraries/modules
 *****************************************************************************/
/* load external module 'Preferences.js' into the scope of 'foxfm
   --> prefix 'foxfm.' need to be used at function calls of this module */
var foxfm = {};
Components.utils.import("resource://modules/Preferences.js", foxfm);
Components.utils.import("resource://gre/modules/FileUtils.jsm");
Components.utils.import("resource://gre/modules/AddonManager.jsm");

/******************************************************************************
 Initialisation of the global variables
 *****************************************************************************/
/* global variables for preference handling */
var prefBranchOFMStrengthLevel		= new foxfm.Preferences("foxfm.pref.ofm.strengthlevel.");
var prefBranchAbout					= new foxfm.Preferences("foxfm.pref.about.");
var prefBranchOFMFunctionSettings	= new foxfm.Preferences("foxfm.pref.ofm.");

/* globals of the extension */
var prefBranchAddOn					= new foxfm.Preferences("foxfm.pref.");

/* global variable saving OFM strength level points */
var gStrengthPoints					= new Array();

/* global variable saving OFM matchday and season */
var gMatchday;

/* global variable saving OFM match information of who is logged in */
var gMatchLeague;
var gMatchFriendly;
var gMatchCup;

/******************************************************************************
 MAIN load (executed only 1 time)
 *****************************************************************************/
function foxfm_load() 
{ 
	window.addEventListener('DOMContentLoaded', foxfm_run, true);
	window.addEventListener('popupshowing', foxfm_initPopupMenu, true);

	gStrengthPoints = foxfm_getOFMStrengthLevel();
	
	infoMessage(1, "foxfm_load(): User Agent: " + navigator.userAgent);
	infoMessage(1, "foxfm_load(): Language: " + getBrowserLanguage());
	
	prefBranchOFMFunctionSettings.reset("bank.active");
	prefBranchOFMFunctionSettings.reset("training.addallattendancecheckbox");
	prefBranchOFMFunctionSettings.reset("training.addfreshnessfilter");
	prefBranchOFMFunctionSettings.reset("training.addawpcalculation")
}

/*******************************************************************************
 * Alternative solution to load jQuery into the Addon. The other way is shown in
 * the foxfm.xul file.
 * --> jquery JavaScript file must be provided!
 */
function loadjQuery(wnd)
{
	var loader = Components.classes["@mozilla.org/moz/jssubscript-loader;1"].getService(Components.interfaces.mozIJSSubScriptLoader);
	loader.loadSubScript("chrome://foxfm/content/resources/jquery/jquery-1.5.1.min.js",wnd);
	var jQuery = wnd.jQuery.noConflict(true);
	return jQuery;
}

function foxfm_run(event) 
{
	try 
	{
		infoMessage(1, "foxfm_run(): started");		
		
		var doc = event.originalTarget;
		
		if (doc.nodeType != doc.DOCUMENT_NODE) 
		{
			doc = doc.ownerDocument;
		}		
		if (!doc || doc == null || doc.location == null || !foxfm_isOFMDomain(doc.location.href)) 
		{
			return;
		}
		
		/* Call all addon function ones */
		if (foxfm_isOFMDomain(doc.location.href))
		{		
			// load jQuery and save it as a property of the window
			// Be sure to choose a name likely to be unique
			// foxfm.jQuery = loadjQuery(window);
			
			// Example to test jQuery if jQuery is loaded via 'loadjQuery()'
			// infoMessage(0, "foxfm_stadium(): " + foxfm.jQuery.browser.version);
			// Example to test jQuery if jQuery is loaded via 'foxfm.xul'
			// infoMessage(0, "foxfm_stadium(): " + $.browser.version);

			foxfm_addJavaScript(doc, "chrome://foxfm/content/resources/js/foxfm_common.js");			
			
			gStrengthPoints = foxfm_getOFMStrengthLevel();
			
			if(foxfm_isOFMDomainBuero(doc.location.href))
			{
				if(foxfm_isOFMGameReportLeague(doc))
				{
					gMatchLeague	= new Foxfm_Match(doc, "League",
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr[1]/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/strong[1]/font[1]/a[1]', 
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/span/font/strong',
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/font/strong/a',
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/font[2]/span/strong'
							);
				}
				if(foxfm_isOFMGameReportFriendly(doc))
				{
					gMatchFriendly	= new Foxfm_Match(doc, "Friendly",
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr[2]/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/strong/font[1]/a[1]',
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr[2]/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/strong/font/span',
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr[2]/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/strong/font[1]/a[2]',
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr[2]/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/span[1]/strong/font[1]'
							);
				}
				if(foxfm_isOFMGameReportCup(doc))
				{
					gMatchCup		= new Foxfm_Match(doc, "Cup",
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr[3]/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/strong[1]/font/a',
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr[3]/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/strong[2]/font/span',
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr[3]/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/strong[2]/font/a',
							'/html/body/div[2]/table/tbody/tr[2]/td[2]/table/tbody/tr[2]/td/div/table/tbody/tr/td[2]/div/table/tbody/tr[3]/td/table/tbody/tr/td[3]/div/table/tbody/tr/td/div/font/span/strong'
					);
				}
			}
			if (foxfm_isOFMDomainHeader(doc.location.href))
			{
				gMatchday		= new Foxfm_Matchday(doc);
				infoMessage(1, "foxfm_run(): gMatchday: " + gMatchday.season + "::" + gMatchday.day);
			}

			foxfm_arm(doc);
			foxfm_bank(doc);
			foxfm_stadium(doc);
			foxfm_team(doc);
			foxfm_team_training(doc);
			foxfm_tm_pros(doc);
			foxfm_tm_amas(doc);
			foxfm_tm_handling(doc);
		}
	} catch (e) {
		errorMessage(e);
	}
}

function foxfm_initPopupMenu(event)
{
    try {         
		if (event.target.id != "contentAreaContextMenu") 
		{
			return;
		}

		var contextMenu = document.getElementById("foxfm_contextMain");

		contextMenu.setAttribute("hidden",!foxfm_isOFMDomain(window._content.document.location.href));
		return;
    } catch (e){
        errorMessage(e);
    }
}

// start foxfm
foxfm_load();